package com.link.core.basic.es.config;

import com.link.core.basic.service.BasicServiceException;
import com.link.core.util.StringUtils;
import java.security.KeyStore;
import javax.net.ssl.SSLContext;
import org.apache.http.HttpHost;
import org.apache.http.auth.AuthScope;
import org.apache.http.auth.UsernamePasswordCredentials;
import org.apache.http.client.CredentialsProvider;
import org.apache.http.conn.ssl.NoopHostnameVerifier;
import org.apache.http.impl.client.BasicCredentialsProvider;
import org.apache.http.nio.conn.ssl.SSLIOSessionStrategy;
import org.apache.http.ssl.SSLContextBuilder;
import org.elasticsearch.client.RestClient;
import org.elasticsearch.client.RestHighLevelClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
@ConfigurationProperties(
   prefix = "elasticsearch"
)
public class ElasticsearchConfig {
   private static final Logger logger = LoggerFactory.getLogger(ElasticsearchConfig.class);
   private String username;
   private String password;
   private String nodes;
   private String configSchema;

   @Bean
   public RestHighLevelClient elasticsearchClient() {
      if (StringUtils.isNotBlank(this.nodes)) {
         String[] split = this.nodes.split(",");
         HttpHost[] httpHosts = new HttpHost[split.length];

         for(int i = 0; i < split.length; ++i) {
            String ipPort = split[i];
            if (!ipPort.contains(":")) {
               throw new BasicServiceException("ip port 格式错误!");
            }

            String[] tmp = ipPort.split(":");
            String ip = tmp[0];
            String port = tmp[1];
            httpHosts[i] = new HttpHost(ip, Integer.parseInt(port), "https");
         }

         logger.info("nodes 集群信息解析完成 {}", httpHosts.length);
         return this.restClient(httpHosts);
      } else {
         throw new BasicServiceException("nodes 信息为空!");
      }
   }

   private RestHighLevelClient restClient(HttpHost[] httpHosts) {
      RestHighLevelClient restClient = null;

      try {
         CredentialsProvider credentialsProvider = new BasicCredentialsProvider();
         credentialsProvider.setCredentials(AuthScope.ANY, new UsernamePasswordCredentials(this.username, this.password));
         SSLContext sslContext = (new SSLContextBuilder()).loadTrustMaterial((KeyStore)null, (chain, authType) -> {
            return true;
         }).build();
         SSLIOSessionStrategy sessionStrategy = new SSLIOSessionStrategy(sslContext, NoopHostnameVerifier.INSTANCE);
         restClient = new RestHighLevelClient(RestClient.builder(httpHosts).setHttpClientConfigCallback((httpClientBuilder) -> {
            httpClientBuilder.disableAuthCaching();
            httpClientBuilder.setSSLStrategy(sessionStrategy);
            httpClientBuilder.setDefaultCredentialsProvider(credentialsProvider);
            return httpClientBuilder;
         }));
      } catch (Exception var6) {
         Exception e = var6;
         e.printStackTrace();
      }

      return restClient;
   }

   public String getUsername() {
      return this.username;
   }

   public void setUsername(String username) {
      this.username = username;
   }

   public String getPassword() {
      return this.password;
   }

   public void setPassword(String password) {
      this.password = password;
   }

   public String getNodes() {
      return this.nodes;
   }

   public void setNodes(String nodes) {
      this.nodes = nodes;
   }

   public String getConfigSchema() {
      return this.configSchema;
   }

   public void setConfigSchema(String configSchema) {
      this.configSchema = configSchema;
   }
}
